﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using System.Runtime.InteropServices;

namespace C_Sharp_Test
{
    public partial class TestForm : Form
    {
        Pulse.ICoDevice pdev;
        Pulse.ICoRecord prec;
        int ipos;
        public TestForm()
        {
            InitializeComponent();
            pdev = null;
            prec = null;
        }

        private void ComCreateButton_Click(object sender, EventArgs e)
        {
            if (pdev == null)
            {
                pdev = new Pulse.CoDevice();
                if (pdev != null)
                    PaintTimer.Enabled = pdev.IsConnected() != 0;
            }
            if (prec == null)
            {
                prec = new Pulse.CoRecord();
            }

            if (pdev != null)
            {
                TextB.Text = "CoDevice OK\r\n";
            }
            else
            {
                TextB.Text = "CoDevice FAILED\r\n";
            }

            if (prec != null)
            {
                TextB.Text += "CoRecord OK";
            }
            else
            {
                TextB.Text += "CoRecord FAILED";
            }
        }

        private void ComDestroyButton_Click(object sender, EventArgs e)
        {
            if (pdev != null)
            {
                Marshal.ReleaseComObject(pdev);
                pdev = null;
            }
            if (prec != null)
            {
                Marshal.ReleaseComObject(prec);
                prec = null;
            }
        }


        private void ConnectButton_Click(object sender, EventArgs e)
        {
            if (pdev == null) return;
            if(pdev.IsConnected() == 0)
                pdev.Connect();
            else
                pdev.Disconnect();

            PaintTimer.Enabled = pdev.IsConnected() != 0;
        }


        private void PaintTimer_Tick(object sender, EventArgs e)
        {
            if (pdev == null) return;

            // process ADC data
            Array sa = pdev.GetRawData();
            int len = sa.GetLength(0);

            System.Windows.Forms.DataVisualization.Charting.Series ps = TestChart.Series.FindByName("TestSeries");
            for(int i = 0; i < len; i++){
                ps.Points.AddXY(ipos * 0.01, sa.GetValue(i));
                ipos++;
            }

            if (ipos > 1000){
                ps.Points.Clear();
                ipos = 0;
            }
            // display numerical values            
            TextB.Text = "HR " + pdev.GetHeartRate() +
                " \r\nDC offset " + pdev.GetDcOffset() +
                " \r\nHF amp " + pdev.GetHfAmp() +
                " \r\nLF amp " + pdev.GetLfAmp();
           
        }
                

        private void RecOpenButton_Click(object sender, EventArgs e)
        {
            if (prec == null) 
                return;
            pdev.Disconnect();
            PaintTimer.Enabled = false;
 
            if (RecOpenDialog.ShowDialog() == DialogResult.OK)
            {
                int res = prec.OpenFile(RecOpenDialog.FileName);
                if (res == 0)
                {
                    TextB.Text = "Can't open " + RecOpenDialog.FileName;
                    return;
                }
                TextB.Text = "OpenFile OK " + RecOpenDialog.FileName;
                RecPosTB.Maximum = (int)prec.GetLength() + 1;
                RecPosTB.Value = 0;
                RecPosTB_ValueChanged(sender, e);
            }
        }

        
        private void RecPosTB_ValueChanged(object sender, EventArgs e)
        {
            if (prec == null) return;
            prec.GoToPos(RecPosTB.Value);

            Array sa = prec.ReadSamples(500);
            int len = sa.GetLength(0);

            System.Windows.Forms.DataVisualization.Charting.Series ps = TestChart.Series.FindByName("TestSeries");
            ipos = 0;
            ps.Points.Clear();
            for (int i = 0; i < len; i++)
            {
                ps.Points.AddXY(ipos * 0.01, sa.GetValue(i));
                ipos++;
            }
                        
            // display numerical values            
            TextB.Text = "HR " + prec.GetHeartRate() +
                " \r\nPos (s) " + prec.GetPos();
        }

    }
}
